#
# spec file for package python-azure-datalake-store
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-azure-datalake-store
Version:        0.0.53
Release:        2.3
Summary:        Microsoft Azure Data Lake Store Client Library
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/Azure/azure-sdk-for-python
Source:         https://files.pythonhosted.org/packages/source/a/azure-datalake-store/azure-datalake-store-%{version}.tar.gz
Source1:        LICENSE.txt
BuildRequires:  %{python_module azure-nspkg >= 3.0.0}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-azure-nspkg >= 3.0.0
Requires:       python-cffi
Requires:       python-requests >= 2.20.0
Requires:       (python-msal >= 1.16.0 with python-msal < 2)
Conflicts:      python-azure-sdk <= 2.0.0
%if 0%{?sle_version} >= 150400
Obsoletes:      python3-azure-datalake-store < 0.0.53
%endif
BuildArch:      noarch

%python_subpackages

%description
This is the Microsoft Azure Data Lake Store Client Library.

Azure Data Lake Store Manager (ARM) is the next generation of management APIs that
replace the old Azure Service Management (ASM).

This package has been tested with Python 2.7, 3.3, 3.4 and 3.5.

%prep
%setup -q -n azure-datalake-store-%{version}

%build
install -m 644 %{SOURCE1} %{_builddir}/azure-datalake-store-%{version}
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%{python_expand # delete common files
rm -rf %{buildroot}%{$python_sitelib}/azure/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/azure/__pycache__
rm -rf %{buildroot}%{$python_sitelib}/samples/__init__.*
rm -rf %{buildroot}%{$python_sitelib}/samples/__pycache__
}

%files %{python_files}
%doc HISTORY.rst README.rst
%license LICENSE.txt
%{python_sitelib}/azure/datalake/
%{python_sitelib}/samples/
%{python_sitelib}/azure_datalake_store-*.dist-info

%changelog
* Thu Apr  4 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Switch package to modern Python Stack on SLE-15
  + Use Python 3.11 on SLE-15 by default
  + Add Obsoletes for old python3 package on SLE-15
  + Drop support for older Python versions
- Switch build system from setuptools to pyproject.toml
  + Add python-pip and python-wheel to BuildRequires
  + Replace %%python_build with %%pyproject_wheel
  + Replace %%python_install with %%pyproject_install
  + Update name for dist directory in %%files section
- Drop setting default file attributes in %%files section
- Use modern RPM macros to express version dependencies
* Tue Mar  5 2024 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.53
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Update Requires from setup.py
* Tue Nov  2 2021 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.52
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Thu Nov 26 2020 Robert Schweikert <rjschwei@suse.com>
- Only build Python3 flavors for distributions 15 and greater
* Thu Nov 12 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.51
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Mon Oct  5 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.50
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Wed Aug 26 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.49
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Move python-futures from BuildRequires to Requires as it is a runtime dependency
* Mon Jan  6 2020 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.48
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
* Fri Oct  4 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.47
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Add python-requires to BuildRequires for Python 2.x
- Drop patch to support older versions of setuptools as
  SLE-12 is now shipping with a recent enough version
  + ads_drop-extras-require.patch
* Thu Apr 11 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.44
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Bump minimum version for namespace packages
  to 3.0.0 in BuildRequires and Requires
- Remove python-devel package from BuildRequires
- Remove unzip package from BuildRequires
- Refresh patches for new version
  + ads_drop-extras-require.patch
- Run fdupes to hardlink duplicate files
  + Add fdupes to BuildRequires
  + Add %%fdupes invocation to %%install
- Update BuildRequires and Requires from setup.py
* Mon Sep  3 2018 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- New upstream release
  + Version 0.0.30
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Drop obsolete patches for new version
  + ads_drop-compatible-releases-operator.patch
- Refresh patches for new version
  + ads_drop-extras-require.patch
- Update Requires from setup.py
* Tue Apr 24 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.0.19
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Move LICENSE.txt from %%doc to %%license section
- Update Requires from setup.py
* Fri Jan 26 2018 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.0.17
  + For detailed information about changes see the
    HISTORY.rst file provided with this package
- Install HISTORY.rst into doc directory
* Thu Oct  5 2017 adrian.glaubitz@suse.com
- Remove versioning for namespace packages in Requires
- Add namespace packages to BuildRequires
- Remove namespace files in %%install target
- Explicitly specify Python files of the package in %%files
* Tue Sep 12 2017 adrian.glaubitz@suse.com
- New upstream release
  + Version 0.0.16
* Wed Jul 26 2017 adrian.glaubitz@suse.com
- Add python-azure-nspkg to Requires
* Wed Jul 26 2017 adrian.glaubitz@suse.com
- Initial build
  + Version 0.0.14
- Add patch to drop compatible releases operator from setup.py,
  required for SLES12 as the setuptools version is too old
  + ads_drop-compatible-releases-operator.patch
- Add patch to drop extras_require field from setup.py,
  required for SLES12 as the setuptools version is too old
  + ads_drop-extras-require.patch
